==> nextcloud-app-calendar-1%3A4.2.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/es_MX.js <==
OC.L10N.register(
    "calendar",
    {
    "%s has published the calendar »%s«" : "%s ha publicado el calendario »%s«",
    "Hello," : "Hola,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Queremos informarte que %s ha publicado el calendario »%s«.",
    "Open »%s«" : "Abrir »%s«",
    "Cheers!" : "¡Saludos!",
    "Appointments" : "Citas",
    "Confirm" : "Confirmar",
    "Where:" : "Dónde:",
    "Calendar" : "Calendario",
    "A Calendar app for Nextcloud" : "Una aplicación de Calendario para Nextcloud",
    "New event" : "Nuevo evento",
    "Today" : "Hoy",
    "Day" : "Día",
    "Week" : "Semana",
    "Month" : "Mes",
    "List" : "Lista",
    "Preview" : "Previsualizar",
    "Copy link" : "Copiar liga",
    "Edit" : "Editar",
    "Delete" : "Borrar",
    "New calendar" : "Nuevo calendario",
    "Export" : "Exportar",
    "Name" : "Nombre",
    "Deleted" : "Eliminado",
    "Restore" : "Restaurar",
    "Delete permanently" : "Borrar permanentemente",
    "Empty trash bin" : "Vaciar la papelera de reciclaje",
    "Share link" : "Compartir liga",
    "Copy public link" : "Copiar enlace público",
    "can edit" : "puede editar",
    "Share with users or groups" : "Compartir con otros usuarios o grupos",
    "Filename" : "Nombre del archivo",
    "Cancel" : "Cancelar",
    "Automatic" : "Automático",
    "or" : "o",
    "List view" : "Vista de lista",
    "Actions" : "Acciones",
    "Show week numbers" : "Mostrar número de semana",
    "Location" : "Ubicación",
    "Description" : "Descripción",
    "to" : "para",
    "Add" : "Agregar",
    "Monday" : "Lunes",
    "Tuesday" : "Martes",
    "Wednesday" : "Miércoles",
    "Thursday" : "Jueves",
    "Friday" : "Viernes",
    "Saturday" : "Sábado",
    "Sunday" : "Domingo",
    "Save" : "Guardar",
    "Update" : "Actualizar",
    "Your email address" : "Tu dirección de correo electrónico",
    "Notification" : "Notificación",
    "Email" : "Correo electrónico",
    "Available" : "Disponible",
    "Unknown" : "Desconocido",
    "Accept" : "Aceptar",
    "Decline" : "Rechazar",
    "Tentative" : "Tentativo",
    "Send email" : "Enviar correo electrónico",
    "All day" : "Todo el día",
    "Repeat" : "Repetir",
    "never" : "nunca",
    "after" : "después",
    "available" : "disponible",
    "More" : "Más",
    "Global" : "Global",
    "Personal" : "Personal",
    "Details" : "Detalles",
    "Attendees" : "Asistentes",
    "Resources" : "Recursos",
    "Close" : "Cerrar",
    "Anniversary" : "Aniversario",
    "Week {number} of {year}" : "Semana {number} de {year}",
    "Daily" : "Diariamente",
    "Weekly" : "Semanalmente",
    "Prev" : "Prev",
    "Next" : "Siguiente",
    "Other" : "Otro",
    "When shared show full event" : "Al compartir, mostrar el evento completo",
    "When shared show only busy" : "Al compartir, mostrar sólo como ocupado ",
    "When shared hide this event" : "Al compartir, ocultar este evento ",
    "Status" : "Estatus",
    "Confirmed" : "Confirmado",
    "Canceled" : "Cancelada",
    "Categories" : "Categorías",
    "Presentation" : "Presentación",
    "Talk" : "Hablar",
    "Office" : "Office",
    "Mail" : "Correo",
    "Birthday" : "Fecha de nacimiento",
    "User not found" : "No se encontró el usuario"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-app-calendar-1%3A4.4.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/es_MX.js <==
OC.L10N.register(
    "calendar",
    {
    "%s has published the calendar »%s«" : "%s ha publicado el calendario »%s«",
    "Hello," : "Hola,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Queremos informarte que %s ha publicado el calendario »%s«.",
    "Open »%s«" : "Abrir »%s«",
    "Cheers!" : "¡Saludos!",
    "Upcoming events" : "Próximos eventos",
    "Calendar" : "Calendario",
    "Appointments" : "Citas",
    "Confirm" : "Confirmar",
    "Where:" : "Dónde:",
    "A Calendar app for Nextcloud" : "Una aplicación de Calendario para Nextcloud",
    "New event" : "Nuevo evento",
    "Today" : "Hoy",
    "Day" : "Día",
    "Week" : "Semana",
    "Month" : "Mes",
    "List" : "Lista",
    "Preview" : "Previsualizar",
    "Copy link" : "Copiar liga",
    "Edit" : "Editar",
    "Delete" : "Borrar",
    "New calendar" : "Nuevo calendario",
    "Export" : "Exportar",
    "Name" : "Nombre",
    "Deleted" : "Eliminado",
    "Restore" : "Restaurar",
    "Delete permanently" : "Borrar permanentemente",
    "Empty trash bin" : "Vaciar la papelera de reciclaje",
    "Internal link" : "Enlace interno",
    "Share link" : "Compartir liga",
    "Copy public link" : "Copiar enlace público",
    "can edit" : "puede editar",
    "Share with users or groups" : "Compartir con otros usuarios o grupos",
    "Save" : "Guardar",
    "Filename" : "Nombre del archivo",
    "Cancel" : "Cancelar",
    "Automatic" : "Automático",
    "or" : "o",
    "List view" : "Vista de lista",
    "Actions" : "Acciones",
    "Show week numbers" : "Mostrar número de semana",
    "Location" : "Ubicación",
    "Description" : "Descripción",
    "Duration" : "Duración",
    "to" : "para",
    "Add" : "Agregar",
    "Monday" : "Lunes",
    "Tuesday" : "Martes",
    "Wednesday" : "Miércoles",
    "Thursday" : "Jueves",
    "Friday" : "Viernes",
    "Saturday" : "Sábado",
    "Sunday" : "Domingo",
    "Update" : "Actualizar",
    "Your email address" : "Tu dirección de correo electrónico",
    "Notification" : "Notificación",
    "Email" : "Correo electrónico",
    "Add from Files" : "Agregar desde Archivos",
    "Delete file" : "Borrar archivo",
    "Choose a file to add as attachment" : "Selecciona el archivo a agregar como adjunto",
    "Available" : "Disponible",
    "Unknown" : "Desconocido",
    "Accept" : "Aceptar",
    "Decline" : "Rechazar",
    "Tentative" : "Tentativo",
    "Send email" : "Enviar correo electrónico",
    "All day" : "Todo el día",
    "Repeat" : "Repetir",
    "never" : "nunca",
    "after" : "después",
    "available" : "disponible",
    "More" : "Más",
    "Pick a time" : "Elige una hora",
    "Pick a date" : "Elige una fecha",
    "Global" : "Global",
    "Subscribe" : "Suscríbete",
    "Personal" : "Personal",
    "No upcoming events" : "No hay eventos próximos",
    "Create a new event" : "Crear un nuevo evento",
    "Details" : "Detalles",
    "Attendees" : "Asistentes",
    "Resources" : "Recursos",
    "Close" : "Cerrar",
    "Anniversary" : "Aniversario",
    "Week {number} of {year}" : "Semana {number} de {year}",
    "Daily" : "Diariamente",
    "Weekly" : "Semanalmente",
    "Other" : "Otro",
    "When shared show full event" : "Al compartir, mostrar el evento completo",
    "When shared show only busy" : "Al compartir, mostrar sólo como ocupado ",
    "When shared hide this event" : "Al compartir, ocultar este evento ",
    "Status" : "Estatus",
    "Confirmed" : "Confirmado",
    "Canceled" : "Cancelada",
    "Categories" : "Categorías",
    "Money" : "Dinero",
    "Presentation" : "Presentación",
    "Talk" : "Hablar",
    "Office" : "Office",
    "Mail" : "Correo",
    "Driving" : "Conducir",
    "Biking" : "Ciclismo",
    "Health" : "Salud",
    "Running" : "Correr",
    "Birthday" : "Fecha de nacimiento",
    "User not found" : "No se encontró el usuario"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
